Method: Google::Api::SelectiveGapicGeneration#methods

Defined in:
proto_docs/google/api/client.rb

#methods::Array<::String>

Returns An allowlist of the fully qualified names of RPCs that should be included on public client surfaces.

Returns:

  • (::Array<::String>)

    An allowlist of the fully qualified names of RPCs that should be included on public client surfaces.



426
427
428
429
# File 'proto_docs/google/api/client.rb', line 426

class SelectiveGapicGeneration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end