Class: Google::Cloud::Spanner::Admin::Database::V1::BackupInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/database/v1/backup.rb

Overview

Information about a backup.

Instance Attribute Summary collapse

Instance Attribute Details

#backup ⇒ ::String

Returns Name of the backup.

Returns:

  • (::String) —

    Name of the backup.



355
356
357
358
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 355

class BackupInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time ⇒ ::Google::Protobuf::Timestamp

Returns The backup contains an externally consistent copy of source_database at the timestamp specified by create_time.

Returns:

  • (::Google::Protobuf::Timestamp) —

    The backup contains an externally consistent copy of source_database at the timestamp specified by create_time.



355
356
357
358
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 355

class BackupInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_database ⇒ ::String

Returns Name of the database the backup was created from.

Returns:

  • (::String) —

    Name of the database the backup was created from.



355
356
357
358
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 355

class BackupInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end