Class: Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/backup.rb
Overview
Encryption configuration for the backup to create.
Defined Under Namespace
Modules: EncryptionType
Instance Attribute Summary collapse
-
#encryption_type ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig::EncryptionType
Required.
-
#kms_key_name ⇒ ::String
Optional.
-
#kms_key_names ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#encryption_type ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig::EncryptionType
615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 615 class CreateBackupEncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encryption types for the backup. module EncryptionType # Unspecified. Do not use. ENCRYPTION_TYPE_UNSPECIFIED = 0 # Use the same encryption configuration as the database. This is the # default option when # {::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig encryption_config} # is empty. For example, if the database is using # `Customer_Managed_Encryption`, the backup will be using the same Cloud # KMS key as the database. USE_DATABASE_ENCRYPTION = 1 # Use Google default encryption. GOOGLE_DEFAULT_ENCRYPTION = 2 # Use customer managed encryption. If specified, `kms_key_name` # must contain a valid Cloud KMS key. CUSTOMER_MANAGED_ENCRYPTION = 3 end end |
#kms_key_name ⇒ ::String
615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 615 class CreateBackupEncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encryption types for the backup. module EncryptionType # Unspecified. Do not use. ENCRYPTION_TYPE_UNSPECIFIED = 0 # Use the same encryption configuration as the database. This is the # default option when # {::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig encryption_config} # is empty. For example, if the database is using # `Customer_Managed_Encryption`, the backup will be using the same Cloud # KMS key as the database. USE_DATABASE_ENCRYPTION = 1 # Use Google default encryption. GOOGLE_DEFAULT_ENCRYPTION = 2 # Use customer managed encryption. If specified, `kms_key_name` # must contain a valid Cloud KMS key. CUSTOMER_MANAGED_ENCRYPTION = 3 end end |
#kms_key_names ⇒ ::Array<::String>
615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 615 class CreateBackupEncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encryption types for the backup. module EncryptionType # Unspecified. Do not use. ENCRYPTION_TYPE_UNSPECIFIED = 0 # Use the same encryption configuration as the database. This is the # default option when # {::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig encryption_config} # is empty. For example, if the database is using # `Customer_Managed_Encryption`, the backup will be using the same Cloud # KMS key as the database. USE_DATABASE_ENCRYPTION = 1 # Use Google default encryption. GOOGLE_DEFAULT_ENCRYPTION = 2 # Use customer managed encryption. If specified, `kms_key_name` # must contain a valid Cloud KMS key. CUSTOMER_MANAGED_ENCRYPTION = 3 end end |