Class: Google::Cloud::Spanner::Admin::Database::V1::CreateBackupMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::CreateBackupMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/backup.rb
Overview
Metadata type for the operation returned by CreateBackup.
Instance Attribute Summary collapse
-
#cancel_time ⇒ ::Google::Protobuf::Timestamp
The time at which cancellation of this operation was received.
-
#database ⇒ ::String
The name of the database the backup is created from.
-
#name ⇒ ::String
The name of the backup being created.
-
#progress ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::OperationProgress
The progress of the CreateBackup operation.
Instance Attribute Details
#cancel_time ⇒ ::Google::Protobuf::Timestamp
243 244 245 246 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 243 class CreateBackupMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#database ⇒ ::String
243 244 245 246 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 243 class CreateBackupMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
243 244 245 246 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 243 class CreateBackupMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#progress ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::OperationProgress
243 244 245 246 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 243 class CreateBackupMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |