Class: Google::Cloud::Spanner::Admin::Database::V1::CreateBackupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::CreateBackupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/backup.rb
Overview
The request for CreateBackup.
Instance Attribute Summary collapse
-
#backup ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::Backup
Required.
-
#backup_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#backup ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::Backup
Returns Required. The backup to create.
113 114 115 116 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 113 class CreateBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#backup_id ⇒ ::String
Returns Required. The id of the backup to be created. The backup_id appended to
parent forms the full backup name of the form
projects/<project>/instances/<instance>/backups/<backup_id>.
113 114 115 116 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 113 class CreateBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the instance in which the backup will be
created. This must be the same instance that contains the database the
backup will be created from. The backup will be stored in the
location(s) specified in the instance configuration of this
instance. Values are of the form
projects/<project>/instances/<instance>.
113 114 115 116 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 113 class CreateBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |