Class: Google::Cloud::Spanner::Admin::Database::V1::EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::EncryptionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/common.rb
Overview
Encryption configuration for a Cloud Spanner database.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ ::String
The Cloud KMS key to be used for encrypting and decrypting the database.
-
#kms_key_names ⇒ ::Array<::String>
Specifies the KMS configuration for the one or more keys used to encrypt the database.
Instance Attribute Details
#kms_key_name ⇒ ::String
67 68 69 70 |
# File 'proto_docs/google/spanner/admin/database/v1/common.rb', line 67 class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kms_key_names ⇒ ::Array<::String>
67 68 69 70 |
# File 'proto_docs/google/spanner/admin/database/v1/common.rb', line 67 class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |