Class: Google::Cloud::Spanner::Admin::Database::V1::ListBackupOperationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::ListBackupOperationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/backup.rb
Overview
The request for ListBackupOperations.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
An expression that filters the list of returned backup operations.
-
#page_size ⇒ ::Integer
Number of operations to be returned in the response.
-
#page_token ⇒ ::String
If non-empty,
page_tokenshould contain a next_page_token from a previous ListBackupOperationsResponse to the sameparentand with the samefilter. -
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
535 536 537 538 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 535 class ListBackupOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
535 536 537 538 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 535 class ListBackupOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
535 536 537 538 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 535 class ListBackupOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
535 536 537 538 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 535 class ListBackupOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |