Class: Google::Cloud::Spanner::Admin::Database::V1::ListBackupOperationsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/database/v1/backup.rb

Overview

The response for .

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token ⇒ ::String

Returns next_page_token can be sent in a subsequent

call to fetch more of the matching metadata.

Returns:

  • (::String) —

    next_page_token can be sent in a subsequent

    call to fetch more of the matching metadata.



339
340
341
342
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 339

class ListBackupOperationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operations ⇒ ::Array<::Google::Longrunning::Operation>

Returns The list of matching backup [long-running operations][google.longrunning.Operation]. Each operation’s name will be prefixed by the backup’s name and the operation’s will be of type . Operations returned include those that are pending or have completed/failed/canceled within the last 7 days. Operations returned are ordered by operation.metadata.value.progress.start_time in descending order starting from the most recently started operation.

Returns:

  • (::Array<::Google::Longrunning::Operation>) —

    The list of matching backup [long-running operations][google.longrunning.Operation]. Each operation’s name will be prefixed by the backup’s name and the operation’s will be of type . Operations returned include those that are pending or have completed/failed/canceled within the last 7 days. Operations returned are ordered by operation.metadata.value.progress.start_time in descending order starting from the most recently started operation.



339
340
341
342
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 339

class ListBackupOperationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end