Class: Google::Cloud::Spanner::Admin::Database::V1::RestoreDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::RestoreDatabaseMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb
Overview
Metadata type for the long-running operation returned by RestoreDatabase.
Instance Attribute Summary collapse
-
#backup_info ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::BackupInfo
Information about the backup used to restore the database.
-
#cancel_time ⇒ ::Google::Protobuf::Timestamp
The time at which cancellation of this operation was received.
-
#name ⇒ ::String
Name of the database being created and restored to.
-
#optimize_database_operation_name ⇒ ::String
If exists, the name of the long-running operation that will be used to track the post-restore optimization process to optimize the performance of the restored database, and remove the dependency on the restore source.
-
#progress ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::OperationProgress
The progress of the RestoreDatabase operation.
-
#source_type ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::RestoreSourceType
The type of the restore source.
Instance Attribute Details
#backup_info ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::BackupInfo
666 667 668 669 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 666 class RestoreDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cancel_time ⇒ ::Google::Protobuf::Timestamp
666 667 668 669 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 666 class RestoreDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
666 667 668 669 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 666 class RestoreDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#optimize_database_operation_name ⇒ ::String
666 667 668 669 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 666 class RestoreDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#progress ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::OperationProgress
666 667 668 669 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 666 class RestoreDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_type ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::RestoreSourceType
666 667 668 669 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 666 class RestoreDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |