Class: Google::Cloud::Spanner::Admin::Database::V1::UpdateDatabaseDdlMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb

Overview

Metadata type for the operation returned by UpdateDatabaseDdl.

Instance Attribute Summary collapse

Instance Attribute Details

#commit_timestamps ⇒ ::Array<::Google::Protobuf::Timestamp>

Returns Reports the commit timestamps of all statements that have succeeded so far, where commit_timestamps[i] is the commit timestamp for the statement statements[i].

Returns:

  • Reports the commit timestamps of all statements that have succeeded so far, where commit_timestamps[i] is the commit timestamp for the statement statements[i].



228
229
230
231
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 228

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#database ⇒ ::String

Returns The database being modified.

Returns:

  • The database being modified.



228
229
230
231
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 228

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#statements ⇒ ::Array<::String>

Returns For an update this list contains all the statements. For an individual statement, this list contains only that statement.

Returns:

  • For an update this list contains all the statements. For an individual statement, this list contains only that statement.



228
229
230
231
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 228

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#throttled ⇒ ::Boolean (readonly)

Returns Output only. When true, indicates that the operation is throttled e.g due to resource constraints. When resources become available the operation will resume and this field will be false again.

Returns:

  • Output only. When true, indicates that the operation is throttled e.g due to resource constraints. When resources become available the operation will resume and this field will be false again.



228
229
230
231
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 228

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end