Class: Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/backup.rb
Overview
Encryption configuration for the backup to create.
Defined Under Namespace
Modules: EncryptionType
Instance Attribute Summary collapse
-
#encryption_type ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig::EncryptionType
Required.
-
#kms_key_name ⇒ ::String
Optional.
Instance Attribute Details
#encryption_type ⇒ ::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig::EncryptionType
Returns Required. The encryption type of the backup.
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 415 class CreateBackupEncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encryption types for the backup. module EncryptionType # Unspecified. Do not use. ENCRYPTION_TYPE_UNSPECIFIED = 0 # Use the same encryption configuration as the database. This is the # default option when # {::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig encryption_config} # is empty. For example, if the database is using # `Customer_Managed_Encryption`, the backup will be using the same Cloud # KMS key as the database. USE_DATABASE_ENCRYPTION = 1 # Use Google default encryption. GOOGLE_DEFAULT_ENCRYPTION = 2 # Use customer managed encryption. If specified, `kms_key_name` # must contain a valid Cloud KMS key. CUSTOMER_MANAGED_ENCRYPTION = 3 end end |
#kms_key_name ⇒ ::String
Returns Optional. The Cloud KMS key that will be used to protect the backup.
This field should be set only when
encryption_type
is CUSTOMER_MANAGED_ENCRYPTION. Values are of the form
projects/<project>/locations/<location>/keyRings/<key_ring>/cryptoKeys/<kms_key_name>.
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'proto_docs/google/spanner/admin/database/v1/backup.rb', line 415 class CreateBackupEncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encryption types for the backup. module EncryptionType # Unspecified. Do not use. ENCRYPTION_TYPE_UNSPECIFIED = 0 # Use the same encryption configuration as the database. This is the # default option when # {::Google::Cloud::Spanner::Admin::Database::V1::CreateBackupEncryptionConfig encryption_config} # is empty. For example, if the database is using # `Customer_Managed_Encryption`, the backup will be using the same Cloud # KMS key as the database. USE_DATABASE_ENCRYPTION = 1 # Use Google default encryption. GOOGLE_DEFAULT_ENCRYPTION = 2 # Use customer managed encryption. If specified, `kms_key_name` # must contain a valid Cloud KMS key. CUSTOMER_MANAGED_ENCRYPTION = 3 end end |