Class: Google::Cloud::Spanner::Admin::Database::V1::CrontabSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::CrontabSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/backup_schedule.rb
Overview
CrontabSpec can be used to specify the version time and frequency at which the backup should be created.
Instance Attribute Summary collapse
-
#creation_window ⇒ ::Google::Protobuf::Duration
readonly
Output only.
-
#text ⇒ ::String
Required.
-
#time_zone ⇒ ::String
readonly
Output only.
Instance Attribute Details
#creation_window ⇒ ::Google::Protobuf::Duration (readonly)
112 113 114 115 |
# File 'proto_docs/google/spanner/admin/database/v1/backup_schedule.rb', line 112 class CrontabSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::String
112 113 114 115 |
# File 'proto_docs/google/spanner/admin/database/v1/backup_schedule.rb', line 112 class CrontabSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#time_zone ⇒ ::String (readonly)
112 113 114 115 |
# File 'proto_docs/google/spanner/admin/database/v1/backup_schedule.rb', line 112 class CrontabSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |