Class: Google::Cloud::Spanner::Admin::Database::V1::UpdateDatabaseDdlMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb

Overview

Metadata type for the operation returned by UpdateDatabaseDdl.

Instance Attribute Summary collapse

Instance Attribute Details

#commit_timestamps ⇒ ::Array<::Google::Protobuf::Timestamp>

Returns Reports the commit timestamps of all statements that have succeeded so far, where commit_timestamps[i] is the commit timestamp for the statement statements[i].

Returns:

  • (::Array<::Google::Protobuf::Timestamp>) —

    Reports the commit timestamps of all statements that have succeeded so far, where commit_timestamps[i] is the commit timestamp for the statement statements[i].



223
224
225
226
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 223

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#database ⇒ ::String

Returns The database being modified.

Returns:

  • (::String) —

    The database being modified.



223
224
225
226
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 223

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#statements ⇒ ::Array<::String>

Returns For an update this list contains all the statements. For an individual statement, this list contains only that statement.

Returns:

  • (::Array<::String>) —

    For an update this list contains all the statements. For an individual statement, this list contains only that statement.



223
224
225
226
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 223

class UpdateDatabaseDdlMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end