Class: Google::Cloud::Spanner::Admin::Database::V1::UpdateDatabaseDdlRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Database::V1::UpdateDatabaseDdlRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb
Overview
Enqueues the given DDL statements to be applied, in order but not
necessarily all at once, to the database schema at some point (or
points) in the future. The server checks that the statements
are executable (syntactically valid, name tables that exist, etc.)
before enqueueing them, but they may still fail upon
later execution (e.g., if a statement from another batch of
statements is applied first and it conflicts in some way, or if
there is some data-related problem like a NULL value in a column to
which NOT NULL would be added). If a statement fails, all
subsequent statements in the batch are automatically cancelled.
Each batch of statements is assigned a name which can be used with the Operations API to monitor progress. See the operation_id field for more details.
Instance Attribute Summary collapse
-
#database ⇒ ::String
Required.
-
#operation_id ⇒ ::String
If empty, the new update request is assigned an automatically-generated operation ID.
-
#proto_descriptors ⇒ ::String
Optional.
-
#statements ⇒ ::Array<::String>
Required.
Instance Attribute Details
#database ⇒ ::String
341 342 343 344 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 341 class UpdateDatabaseDdlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#operation_id ⇒ ::String
341 342 343 344 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 341 class UpdateDatabaseDdlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#proto_descriptors ⇒ ::String
341 342 343 344 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 341 class UpdateDatabaseDdlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#statements ⇒ ::Array<::String>
341 342 343 344 |
# File 'proto_docs/google/spanner/admin/database/v1/spanner_database_admin.rb', line 341 class UpdateDatabaseDdlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |